#!/usr/bin/python

# apply sigma values to h strips

# take sigma values for each grid cell previously calculated with make_sigma.py,
# multiply that with each h strip to produce sigma*h, and store that result.

import sys
import numpy
import shutil
import os
import getopt

from utils import *

#########################################################################
def usage():

        print "Usage: hsigma.py [-c configfile] sigmafile"
        print "where "
        print"    sigmafile is file with sprior sigma values."

#########################################################################


configfile = "config.ini"
try:
        opts, args = getopt.getopt(sys.argv[1:], "c:")
except getopt.GetoptError, err:
        # print help information and exit:
        print str(err) # will print something like "option -a not recognized"
        usage()
        sys.exit()

for o, a in opts:
        if o == "-c":
                configfile = a

if len(args) != 1:
        usage()
        sys.exit()


sigmafile = args[0]


config = getConfig(configfile)
ntimesteps = config["ntimesteps"]

try:
	sigma = numpy.load(sigmafile)
except:
        try:
		landmask = numpy.load(config["landmask_file"])
                sigma = getSpriorNetcdf(sigmafile, "sigma", landmask)
        except:
                print "Cannot read sigma file."
                sys.exit()


# set the directory where the H slices will be stored.
hsigdir = config["workdir"] + "/" + config["hsigdir"]
if os.path.exists(hsigdir):
	# remove any files in the hdir.
	shutil.rmtree(hsigdir)

# create the h directory
try:
	os.makedirs(hsigdir)
except:
	sys.exit("Can't make directory for hsigma files: %s" % hsigdir)

t1 = datetime.datetime.now()

for j in range(ntimesteps):

	# h slice files are numbered 1 .. ntimesteps
	hfile = config["workdir"] + "/" + config["hdir"] + "/H%04d.bin" % (j+1)
	h = binread_sparse(hfile)
#	zz = h.todense()
#	print zz.shape

#	print sigma[j].shape
#	sys.exit()

	b = numpy.multiply(h.todense(), sigma[j])

	hsigfile = config["workdir"] + "/" + config["hsigdir"] + "/H%04d.bin" % (j+1)
	binwrite_sparse(hsigfile, b)

	t2 = datetime.datetime.now()
	print j, hsigfile, t2 - t1

#	sys.exit()
