
"""
Create a landmask array file for use in north america ctlpdm inversions.

Requires:
	ctregions.nc - File with 0/1 for global 1 degree cells created from
	CarbonTracker data.
	config file - Configuration file

Output
	region.npy - A numpy file with 0/1 designation for land cells in domain
	region.txt - Same as region.nc but in text format, rows = latitudes, columns = longitudes
	landmask file - numpy file with location of land cells in domain
		This is a 2xnumlandcells array. Dimension 0 has latitude cell numbers with land,
		dimension 1 has longitude cell numbers with land.
"""

import getopt
import netCDF4

from utils import *


####################################################
def usage():

        print """
Usage: mklm.py [-c configfile] regions_file

where 
        regions_file is netcdf file with a 'regions' variable for the globe,
	which has 1/0 values for land/ocean grid cells.
	"""

####################################################

configfile = "config.ini"

try:
    opts, args = getopt.getopt(sys.argv[1:], "c:")
except getopt.GetoptError, err:
    # print help information and exit:
    print str(err) # will print something like "option -a not recognized"
    usage()
    sys.exit()

for o, a in opts:
    if o == "-c":
        configfile = a


config = getConfig(configfile)

if len(args) != 1:
	usage()
	sys.exit()

regionsfile = args[0]

# Read in carbontracker regions file. This has 0/1 for each global 1 degree grid cell
ds = netCDF4.Dataset(regionsfile)
regions = ds.variables['regions'][:]
map_na = regions[config["latmin"]:config["latmax"]+1, config["lonmin"]:config["lonmax"]+1]

# remove tip of south america
# latitude < 15 deg, longitude < -80 deg
map_na[0:5, 90:120] = 0

# remove greenland
# latitude > 60 deg, longitude < -60 deg
map_na[50:, 110:] = 0

# northwest tip of greenland
# latitude > 70 deg, longitude < -73 deg
map_na[60:, 97:] = 0

numpy.save("region", map_na)
numpy.savetxt("region.txt", map_na, fmt="%.0f")

# find the indices in the map_na array where there is land.
landmaparr = numpy.where(map_na == 1)
#print landmaparr


numpy.save(config["landmask_file"], landmaparr)
